"""
Operaciones matemáticas básicas

Este módulo contiene funciones para realizar operaciones matemáticas
fundamentales: suma, resta, multiplicación y división.
"""

def suma(a, b):
    """
    Realiza la suma de dos números.
    
    Args:
        a: Primer número
        b: Segundo número
        
    Returns:
        float: Resultado de la suma a + b
        
    Examples:
        >>> suma(5, 3)
        8.0
        >>> suma(2.5, 1.5)
        4.0
    """
    return float(a + b)

def resta(a, b):
    """
    Realiza la resta de dos números.
    
    Args:
        a: Primer número (minuendo)
        b: Segundo número (sustraendo)
        
    Returns:
        float: Resultado de la resta a - b
        
    Examples:
        >>> resta(5, 3)
        2.0
        >>> resta(2.5, 1.5)
        1.0
    """
    return float(a - b)

def multiplicacion(a, b):
    """
    Realiza la multiplicación de dos números.
    
    Args:
        a: Primer número
        b: Segundo número
        
    Returns:
        float: Resultado de la multiplicación a * b
        
    Examples:
        >>> multiplicacion(5, 3)
        15.0
        >>> multiplicacion(2.5, 2)
        5.0
    """
    return float(a * b)

def division(a, b):
    """
    Realiza la división de dos números.
    
    Args:
        a: Primer número (dividendo)
        b: Segundo número (divisor)
        
    Returns:
        float: Resultado de la división a / b
        
    Raises:
        ZeroDivisionError: Si el divisor es cero
        
    Examples:
        >>> division(6, 2)
        3.0
        >>> division(5, 2)
        2.5
    """
    if b == 0:
        raise ZeroDivisionError("No se puede dividir por cero")
    return float(a / b)

# Ejemplos de uso
if __name__ == "__main__":
    print("Ejemplos de uso del módulo operaciones:")
    print(f"Suma: 5 + 3 = {suma(5, 3)}")
    print(f"Resta: 10 - 4 = {resta(10, 4)}")
    print(f"Multiplicación: 6 * 7 = {multiplicacion(6, 7)}")
    print(f"División: 15 / 3 = {division(15, 3)}")
    
    try:
        print(f"División por cero: {division(5, 0)}")
    except ZeroDivisionError as e:
        print(f"Error: {e}")
